/************************************************************************************
  This is your Page Code. The appAPI.ready() code block will be executed on every page load.
  For more information please visit our docs site: http://docs.crossrider.com
*************************************************************************************/

appAPI.ready(function($) {
	
	var _hknURL = 'http://www2.helfen-kostet-nix.de';
    var _shopsURL = _hknURL + '/shops/shops_json';
    var _projectURL = _hknURL + '/projects/get_cookie';
    var _shops = false;
    var _retryTimeout = 2000;
    var _retryMaxCount = 10;
    var _selShop = '';
    var _selProject = '';                                       
    var _selProjectLogo = '';                                   
    var _selProjectName = '';
    var _clickoutActiveKeepAlive = 60;
    var _isHiddenKeepAlive = 60 * 24;
    var _projectNameLengthLimit = 100;
    var _tabId = false;

    var _TPL_DEFAULT = 'tpl/toolbar-default.html';
    var _TPL_ERROR = 'tpl/toolbar-error.html';
    var _TPL_PARTNER = 'tpl/toolbar-partnershop.html';
    var _TPL_NOPARTNER = 'tpl/toolbar-nopartner.html';
    var _TPL_ACTIVE = 'tpl/toolbar-activeshop.html';
    var _TPL_NOPROJECT = 'tpl/toolbar-noproject.html';
    var _TPL_EXCLUSIVE = 'tpl/toolbar-exclusive.html';
    
    if (appAPI.isMatchPages(
        "partners.webmasterplan*",
        "ad.zanox.*",
        "www.zanox-affiliate.*"
    )) {
    } else {
        init();
    }
    
    function init() {
        _tabId = 'tab-' + appAPI.getTabId();

        var hknURLFromDb = appAPI.db.get('hknURL');
        if (hknURLFromDb !== '' && hknURLFromDb !== null) {
            _hknURL = hknURLFromDb;
            _projectURL = _hknURL + '/projects/get_cookie';
        } else {
        }

        if (checkPageUrl()) {
            appAPI.message.addListener({}, function (msg) {
                if (msg.action === 'browserActionClicked') {
                    onBrowserActionClick();
                }
            });

            getShops(function (success) {
                initTab();
            });
        } else {
        	
        	getProjectData(_retryMaxCount, function (success) {
            }, true);
        	
        }
    }
    
    function initTab() {
        appAPI.resources.includeCSS('css/iframe.css');
		$('body').first().prepend(appAPI.resources.parseTemplate('tpl/iframe.html', {}));
        appAPI.db.async.get('shops', function (shops) {
            _shops = appAPI.JSON.parse(shops);

            getProjectData(_retryMaxCount, function (success) {
                drawToolbar();
            });
        });
    }
    
    function checkPageUrl() {
        var pageUrl = location.href;
        var host = appAPI.utils.getHost(pageUrl);
        var domain = appAPI.utils.getDomain(pageUrl);

        if (appAPI.appInfo.environment === 'staging') {
            if (host === 'helfen-kostet-nix.de' || host === 'www.helfen-kostet-nix.de' || host === 'www2.helfen-kostet-nix.de') {
                setToolbarInstallationMode('live');
            }
            else if (host === 'hkndev.marcnoller.de') {
                setToolbarInstallationMode('dev');
            }
        }
        else {
            setToolbarInstallationMode('live');
        }

        if ((host.indexOf('helfen-kostet-nix') !== -1 && (pageUrl.indexOf('/shops/visit_toolbar/')) !== -1)) {
			
            var projectUrlKey = pageUrl.match(/\/([0-9]+)$/);
            var shopUrlKey = pageUrl.match(/\/shops\/visit_toolbar\/([0-9]+)\//i);

            if (projectUrlKey.length > 0 && shopUrlKey.length > 0) {
				shopUrlKey = shopUrlKey[1];
				_selShop = shopUrlKey;
                projectUrlKey = projectUrlKey[1];
                _selProject = projectUrlKey;
				
				appAPI.db.set('ss-' + _tabId, _selShop);
                appAPI.db.set('sp-' + _tabId, _selProject);
                appAPI.db.set('coa-' + _tabId, true, appAPI.time.minutesFromNow(_clickoutActiveKeepAlive));

                return false;
            }
            else {
            }
        }

        return true;
    }
    
    function setToolbarInstallationMode(mode) {
        var url = 'http://www2.helfen-kostet-nix.de';

        switch (mode) {
            case 'live':
                url = 'http://www2.helfen-kostet-nix.de';
                break;

            case 'dev':
                url = 'http://hkndev.marcnoller.de';
                break;
        }

        if (_hknURL !== url) {
            _hknURL = url;
            appAPI.db.set('hknURL', _hknURL);
            _projectURL = _hknURL + '/projects/get_cookie';
        }
    }
    
    function getProjectData(retry, callback, force) {
        if (!appAPI.utils.isDefined(retry)) {
            retry = _retryMaxCount;
        }

        appAPI.request.get({
            url: _projectURL,
            onSuccess: function (response, additionalInfo) {

                if (appAPI.utils.isDefined(response.success)) {
                }
                else {
                    response = appAPI.JSON.parse(response);
                }

                if (response.success) {
					_projectData = response.data;
					_selProject = _projectData.selectedProject ? _projectData.selectedProject : '';
                    _selProjectLogo = _projectData.selectedProjectImage ? _projectData.selectedProjectImage : '';
                    _selProjectName =  _projectData.selectedProjectName ?  _projectData.selectedProjectName : '';
                    appAPI.db.remove('ish-' + _tabId);
					
                    // Save in local db
                    appAPI.db.set('sp-' + _tabId, _selProject);
                    appAPI.db.set('spi-' + _tabId, _selProjectLogo);
                    appAPI.db.set('spn-' + _tabId, _selProjectName);
                    
                }
                else {
                }

                // Callback!
                if (appAPI.utils.isDefined(callback)) {
                    callback(true);
                }
            },
            onFailure: function (httpCode) {
                if (retry > 0) {
                    appAPI.setTimeout(function () {
                        retry = retry - 1;
                        getProjectData(retry, callback);
                    }, _retryTimeout);
                } else {
                	
                    // Callback!
                    if (appAPI.utils.isDefined(callback)) {
                        callback(false);
                    }
                }
            },
            responseDataType: 'application/json'
        });
    }
    

    function drawToolbar(forceVisibility) {
        var isPartner = checkIfPartner();
        var isHidden = $('#hkn-toolbar-wrapper').is(":visible");

        var show = !isHidden;

        if (isPartner) {
            show = true;
        } else {
            show = false;
        }
		
        if (appAPI.utils.isDefined(forceVisibility)) {

            if (forceVisibility === true)
                show = true;
            else
                show = false;
        }

        // Never show Toolbar on redirect page and organization choose page
        if (appAPI.isMatchPages(
            "helfen-kostet-nix.de/shops/visit_toolbar/*",
            "*.helfen-kostet-nix.de/shops/visit_toolbar/*",
            "helfen-kostet-nix.de/shops/visit/*",
            "*.helfen-kostet-nix.de/shops/visit/*"
        )) {
            show = false;
        }

        // Never show if it is switched off
        var pageUrl = location.href;
        var domain = appAPI.utils.getDomain(pageUrl);
        var isHiddenSwitch = appAPI.db.get('ish-' + _tabId);
        if (isHiddenSwitch) {

            if (appAPI.utils.isDefined(isHiddenSwitch[domain]) && isHiddenSwitch[domain] === 1) {
                show = false;
            }
        }

        var clickoutActive = appAPI.db.get('coa-' + _tabId);
        var installation = '';

        switch (_hknURL) {

            case 'http://www2.helfen-kostet-nix.de':
                installation = ''; // Show nothing for live mode
                break;

            case 'http://hkndev.marcnoller.de':
                installation = 'dev';
                break;
        }
		
        if (clickoutActive) {
			var _selShop = appAPI.db.get('ss-' + _tabId);
            if ((isPartner && _selShop !== isPartner.Shop.id) || (!isPartner)) {
                clickoutActive = false;
                appAPI.db.set('coa-' + _tabId, false, appAPI.time.minutesFromNow(_clickoutActiveKeepAlive));
                appAPI.db.remove('ish-' + _tabId);
                if (isPartner) show = true;
            }
        }
        else {

            if (!isPartner) {
                appAPI.db.remove('ish-' + _tabId);
            } else if (isPartner) {
                var lastShop = appAPI.db.get('lastShop-' + _tabId);

                if (lastShop !== isPartner.Shop.id) {
                    appAPI.db.remove('ish-' + _tabId);
                }
            }
        }
		
        // Save the last partner shop
        if (isPartner) {
            appAPI.db.set('lastShop-' + _tabId, isPartner.Shop.id);
        }
        else {
            appAPI.db.set('lastShop-' + _tabId, '');
        }

        // Select Toolbar template
        var tmpFile = _TPL_DEFAULT;
		
        if (isPartner) {
			
			if(isPartner.Shop.description=='hkn_exclusive') {
				tmplFile = _TPL_EXCLUSIVE;
				var partner_id = isPartner.Shop.shop_pid;
				var provision = "";
				
			} else {
			
            	// Active clickout for this partner shop
            	if (clickoutActive === true && _selProject !== null && _selProject !== false && _selProject !== '') {
                	tmplFile = _TPL_ACTIVE;
            	} else if (_selProject === null || _selProject === false || _selProject === '') {
                	tmplFile = _TPL_NOPROJECT;
            	} else {
                	tmplFile = _TPL_PARTNER;
            	}
            
            	var provision = isPartner.Shop.rate;
			}
            
        }
        else {
            tmplFile = _TPL_NOPARTNER;
            var provision = "";
        }
		
		// Build URL for shop visit
		if (isPartner) {
			var ProjectLink = _hknURL + '/shops/visit_toolbar/' + isPartner.Shop.id + '/' + _selProject;
		} else {
			var ProjectLink = _hknURL + '/shops/visit_toolbar/1/' + _selProject;
		}
		
		// Replace backslashes
		_selProjectName = _selProjectName.replace(/\\/g, '');
		
        // Shorten project name
        var _selProjectNameShortened = _selProjectName;
        if (_selProjectName.length > _projectNameLengthLimit) {
            _selProjectNameShortened = _selProjectName.substr(0, _projectNameLengthLimit) + ' ...';
        }

        // Parse Toolbar template
        var tmpl = $(appAPI.resources.parseTemplate(tmplFile, {
            hknURL: _hknURL,
            selProject: _selProject,
            selProjectLogo: _selProjectLogo ? _hknURL + _selProjectLogo : '',
            selProjectName: _selProjectName ? _selProjectNameShortened : '',
            partnerShop: isPartner,
            clickoutActive: clickoutActive,
            ProjectLink: ProjectLink,
            provision: provision
        }));

        // Inject images from resources folder
        $(tmpl).find('#logo').attr('src', appAPI.resources.getImage('img/logo_h.png'));
		
        switch (tmplFile) {

            case _TPL_DEFAULT:
                break;

            case _TPL_ERROR:
                break;
			
			case _TPL_NOPROJECT:
				$(tmpl).find('#buttonimg').attr('src', appAPI.resources.getImage('img/choose_project.png'));
                break;
			
            case _TPL_PARTNER:
                $(tmpl).find('#buttonimg').attr('src', appAPI.resources.getImage('img/button.png'));
                break;

            case _TPL_NOPARTNER:
                break;

            case _TPL_ACTIVE:
                $(tmpl).find('#buttonimg').attr('src', appAPI.resources.getImage('img/active.png'));
                break;
            
            case _TPL_EXCLUSIVE:
            	$(tmpl).find('#exclusive_link').attr('href', 'http://www2.helfen-kostet-nix.de/partner/'+partner_id);
                break;
        }


        $(tmpl).appendTo($('#hkn-toolbar-iframe').contents().find('body'));

        if (show) {
            $('#hkn-toolbar-wrapper').css('display', 'block');
        }

        var css = appAPI.resources.get('css/toolbar.css');
        $('<style type="text/css">' + css + '</style>').appendTo($('#hkn-toolbar-iframe').contents().find('body'));

        // Add toggle button
        var $ti = $(tmpl).find('#toogleimg');
        $ti.attr('src', appAPI.resources.getImage('img/hide.png'));
        $ti.click(function (e) {
            e.preventDefault();
            onBrowserActionClick();
            return false;
        });
    }

    function getShops(callback) {
        initShops(_retryMaxCount, function (success) {
            callback(success);
        });
    }
    
    function checkIfPartner() {
        var isPartner = false;
        if (_shops === false) {
        } else {
            var shopCount = _shops.shoplist.length;
            for (var i = 0; i < shopCount; i++) {
                var shop = _shops.shoplist[i];
                if (appAPI.isMatchPages(shop.Shop.base_url, '*.' + shop.Shop.base_url)) {
                    isPartner = shop;
                    break;
                }
            }
        }

        return isPartner;
    }
    
    function initShops(retry, callback) {

        if (!appAPI.utils.isDefined(retry)) {
            retry = _retryMaxCount;
        }

        appAPI.db.async.get("shops", function (shops) {
            if (shops) {
                _shops = shops;
                if (appAPI.utils.isDefined(callback)) {
                    callback(true);
                }
            } else {
                appAPI.db.async.setFromRemote(
                    _shopsURL,
                    "shops",
                    appAPI.time.daysFromNow(1),
                    function (response) {
                        _shops = appAPI.JSON.parse(response);
                        if (appAPI.utils.isDefined(callback)) {
                            callback(true);
                        }
                    },
                    function (httpCode) {
                        if (retry > 0) {
                            appAPI.setTimeout(function () {
                                retry = retry - 1;
                                initShops(retry);
                            }, _retryTimeout);
                        }
                        else {
                            if (appAPI.utils.isDefined(callback)) {
                                callback(false);
                            }
                        }
                    }
                );
            }
        });
    }

    
    function onBrowserActionClick() {
        $('#hkn-toolbar-wrapper').toggle();
        var isVisible = $('#hkn-toolbar-wrapper').is(":visible");
        var pageUrl = location.href;
        var domain = appAPI.utils.getDomain(pageUrl);
        var isHidden = appAPI.db.get('ish-' + _tabId);
        if (!appAPI.utils.isDefined(isHidden) || isHidden == null) {
            isHidden = {};
        }

        if (isVisible) {
            isHidden[domain] = 0;
        } else {
            isHidden[domain] = 1;
        }

        appAPI.db.set('ish-' + _tabId, isHidden, appAPI.time.minutesFromNow(_isHiddenKeepAlive));
    }
    
});
